//+------------------------------------------------------------------+
//|                                                       Pin%.mq4 |
//|                        Copyright 2012, MetaQuotes Software Corp. |
//|                                        http://www.metaquotes.net |
//+------------------------------------------------------------------+

//1) The Indicator will display a arrow (or smiley face, etc...) when the specified criteria are met.

//2) The Indicator will work out the PERCENTAGE of the WICK in comparison to the OVERALL candle (High/Low).
//a) It will work out The High Wick Percentage, and The Low Wick Percentage INDEPENDENTLY.
//3) The Indicator will have a numerical value (in percent) that can be set as a personal tolerance.
//Ie: I could enter '10%' and it will show results only for criteria BELOW 10%, (Or 5%, or 25%, etc...) 
//The figure should be arbitrary and to the specific users preference.

//4) The 3 possible scenarios it should be able to filter for are as follows:
//A) IF a BULL Bar  The pre-defined tolerance filter is only applied to TOP of Wick
//B) If a BEAR Bar  The pre-defined tolerance filter is only applied to BOTTOM of Wick
//C) An option to switch on the pre-defined tolerance filter for only when BOTH TOP & BOTTOM criteria to be met

//Because the indicator works by simply saying whether a candle meets the conditions or not - 
//I do not want it to display the actual numeric value of the candle wicks that do qualify - that is irrelevant. 

extern string  StringA              = "0 for current timeframe, 5 for 5 mins....";
extern int     TimeType             = 0; // 

extern string  StringB              = "1 for Bull, 2 for Bear, 0 for Both.";
extern int     ScenarioFilter       = 0; // 

extern string  StringC              = "1 for > High, 2 for < Low, 0 for Both.";
extern int     HighLowPercentShow   = 0; // 

extern string  StringD              = "Percentage value in numbers (int) only.";
extern int     HighPercentage       = 70;
extern int     LowPercentage        = 10;

extern int     PeriodLookBack       = 2000;

bool        Restart                 = true;
int         Time_1                  = 0;                    //NewBar1() 
string      Signal_Bar1             = "Close";              //NewBar1()
bool        NewBarSignal1           = false;                //NewBar1() 

void init()
  {
      ObjectsDeleteAll();
      Restart                 = true;
  }

void start()
   {
      TimeSignal();
      if ( Restart || NewBarSignal1)
            Wicked();
      Restart        = false;
      Signal_Bar1    = "Close";
   }

void Wicked()
   {
      if ( Restart)
            int b = PeriodLookBack;
      if ( !Restart)
            b = 1;
      for (int a = b; a>=1; a--)
         {
            double HighestHigh       =  iHigh(Symbol(),TimeType,a);
            double LowestLow         =  iLow(Symbol(),TimeType,a);
            double HighLowSize           = HighestHigh - LowestLow;
            
            bool BullBar = false;
            bool BearBar = false;
            
            double OpenCloseHigh     = 0;
            double OpenCloseLow      = 999999;
            
            if ( iClose(Symbol(),TimeType,a) > iOpen(Symbol(),TimeType,a))
               {
                  OpenCloseHigh     = iClose(Symbol(),TimeType,a);
                  OpenCloseLow      = iOpen(Symbol(),TimeType,a);
                  BullBar           = true;
               }
            if (iClose(Symbol(),TimeType,a) < iOpen(Symbol(),TimeType,a))
               {
                  OpenCloseHigh     = iOpen(Symbol(),TimeType,a); 
                  OpenCloseLow      = iClose(Symbol(),TimeType,a);
                  BearBar           = true;
               }
            double TopWickPercentage       = (HighestHigh  - OpenCloseHigh)/HighLowSize * 100;
            double BottomWickPercentage    = (OpenCloseLow - LowestLow)/HighLowSize * 100;
            if ( HighLowPercentShow == 0 || HighLowPercentShow == 1) // for both or > high.
               {
                  if ( (ScenarioFilter == 0 || (ScenarioFilter == 1 && BullBar) )&& TopWickPercentage > HighPercentage) // for both or bull
                     {
                        DisplayWick(TopWickPercentage,"Top","High",a);
                     }
                  if ( (ScenarioFilter == 0 || (ScenarioFilter == 2 && BearBar) ) && BottomWickPercentage > HighPercentage) // for both or bear
                     {
                        DisplayWick(BottomWickPercentage,"Bottom","High",a);
                     }
               }
            if ( HighLowPercentShow == 0 || HighLowPercentShow == 2) // for both or < Low.
               {
                  if ( (ScenarioFilter == 0 || (ScenarioFilter == 1 && BullBar )) && TopWickPercentage < LowPercentage) // for both or bull
                     {
                        DisplayWick(TopWickPercentage,"Top","Low",a);
                     }
                  if ( (ScenarioFilter == 0 || (ScenarioFilter == 2 && BearBar)) && BottomWickPercentage < LowPercentage)// for both or bear
                     {
                        DisplayWick(BottomWickPercentage,"Bottom","Low",a);
                     }
               }
         }
   } 
void DisplayWick(int WickPercentage,string TopBottom,string HighLow,int bars)
   {
      double   HighestHigh       = iHigh(Symbol(),TimeType,bars);
      double   LowestLow         = iLow(Symbol(),TimeType,bars);
      datetime WickDateTime      = iTime(Symbol(),TimeType,bars);
      color    TopLineColor      = Black;
      color    BottomLineColor   = Black;
      double   TopWickPrice      = 0;
      double   BottomWickPrice   = 0;
      if ( TopBottom == "Top")
         {
            if (HighLow == "High")
               {
                  TopWickPrice   = HighestHigh + 15 * Point;
                  TopLineColor   = Magenta;
               }
            if (HighLow == "Low")
               {
                  TopWickPrice = HighestHigh + 15 * Point;
                  TopLineColor   = Yellow;
               }
            string Top_name = HighLow +" : "+WickPercentage+ " : "+bars;
            if (ObjectFind(Top_name) !=1)
                  ObjectDelete(Top_name);
            ObjectCreate(Top_name, OBJ_TEXT, 0, WickDateTime, TopWickPrice);
            ObjectSetText(Top_name, CharToStr(164), 10, "Wingdings", TopLineColor);//""
         }
      if ( TopBottom == "Bottom")
         {
            if (HighLow == "High")
               {
                  BottomWickPrice = LowestLow - 15 * Point;
                  BottomLineColor = Yellow;
               }
            if (HighLow == "Low")
               {
                  BottomWickPrice = LowestLow - 15 * Point;
                  BottomLineColor = Yellow;
               }
            string Bottom_name = HighLow +" : "+WickPercentage+ " : "+bars;
            if (ObjectFind(Bottom_name ) !=1)
                  ObjectDelete(Bottom_name );
            ObjectCreate(Bottom_name , OBJ_TEXT, 0, WickDateTime, BottomWickPrice);
            ObjectSetText(Bottom_name , CharToStr(164), 10, "Wingdings", BottomLineColor);//""
         }
   }
  
void TimeSignal()
   {
      NewBar1();
   }
void NewBar1()  // 
   {
      if ( Signal_Bar1 == "Close") 
         {
            if ( Time_1    < iTime ( 0 , TimeType , 0 ) )
               { 
                  Time_1   = iTime ( 0 , TimeType , 0 ) ; 
                  NewBarSignal1 = true;
                  Signal_Bar1 = "Open"; 
               }
            else     
               {
                  NewBarSignal1 = false; 
               }
         }
   }
void deinit()
  {
  }